@@ -11,6 +11,7 @@
 
 #define _XOPEN_SOURCE
 #include "config.h"
+#include "custom.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -247,6 +248,28 @@ static void WriteBottomCalLine (void);
 static void WriteIntermediateCalLine (void);
 static void WriteCalDays (void);
 
+static char const *
+despace(char const *s)
+{
+    static char buf[256];
+
+    char *t = buf;
+    if (strlen(s) > sizeof(buf)-1) {
+        /* Punt. :( */
+        return s;
+    }
+    while (*s) {
+        if (isspace(*s)) {
+            *t++ = '_';
+        } else {
+            *t++ = *s;
+        }
+        s++;
+    }
+    *t = 0;
+    return buf;
+}
+
 void PrintJSONString(char const *s)
 {
     while (*s) {
@@ -268,7 +291,7 @@ void PrintJSONKeyPairInt(char const *name, int val)
 {
     printf("\"");
     PrintJSONString(name);
-    printf("\":%d, ", val);
+    printf("\":%d,", val);
 }
 
 void PrintJSONKeyPairString(char const *name, char const *val)
@@ -282,7 +305,7 @@ void PrintJSONKeyPairString(char const *name, char const *val)
     PrintJSONString(name);
     printf("\":\"");
     PrintJSONString(val);
-    printf("\", ");
+    printf("\",");
 }
 
 void PrintJSONKeyPairDate(char const *name, int jul)
@@ -295,7 +318,7 @@ void PrintJSONKeyPairDate(char const *name, int jul)
     FromJulian(jul, &y, &m, &d);
     printf("\"");
     PrintJSONString(name);
-    printf("\":\"%04d-%02d-%02d\", ", y, m+1, d);
+    printf("\":\"%04d-%02d-%02d\",", y, m+1, d);
 
 }
 
@@ -313,7 +336,7 @@ void PrintJSONKeyPairDateTime(char const *name, int dt)
     i = k % 60;
     printf("\"");
     PrintJSONString(name);
-    printf("\":\"%04d-%02d-%02dT%02d:%02d\", ", y, m+1, d, h, i);
+    printf("\":\"%04d-%02d-%02dT%02d:%02d\",", y, m+1, d, h, i);
 
 }
 
@@ -328,7 +351,7 @@ void PrintJSONKeyPairTime(char const *name, int t)
     i = t % 60;
     printf("\"");
     PrintJSONString(name);
-    printf("\":\"%02d:%02d\", ", h, i);
+    printf("\":\"%02d:%02d\",", h, i);
 
 }
 
@@ -346,6 +369,41 @@ static void PutWideChar(wchar_t const wc)
 }
 #endif
 
+static char const *
+get_month_abbrev(char const *mon)
+{
+    static char buf[80];
+#ifndef REM_USE_WCHAR
+    sprintf(buf, "%.3s", mon);
+    return buf;
+#else
+    char *s;
+    wchar_t tmp_buf[128];
+    wchar_t *ws;
+    int i;
+    int len;
+
+    *buf = 0;
+    (void) mbstowcs(tmp_buf, mon, 127);
+    ws = tmp_buf;
+    s = buf;
+    for (i=0; i<3; i++) {
+        if (*ws) {
+            len = wctomb(s, *ws);
+            s += len;
+            if (wcwidth(*ws) == 0) {
+                i--;
+            }
+            ws++;
+        } else {
+            break;
+        }
+    }
+    *s = 0;
+    return buf;
+#endif
+}
+
 static int make_wchar_versions(CalEntry *e)
 {
 #ifdef REM_USE_WCHAR
@@ -543,9 +601,11 @@ void ProduceCalendar(void)
     ColSpaces = (CalWidth - 9) / 7;
     CalWidth = 7*ColSpaces + 8;
 
+    /* Run the file once to get potentially-overridden day names */
     if (CalMonths) {
-	FromJulian(JulianToday, &y, &m, &d);
-	JulianToday = Julian(y, m, 1);
+        FromJulian(JulianToday, &y, &m, &d);
+        JulianToday = Julian(y, m, 1);
+        GenerateCalEntries(-1);
 	DidAMonth = 0;
 	if (PsCal == PSCAL_LEVEL3) {
 	    printf("[\n");
@@ -562,6 +622,8 @@ void ProduceCalendar(void)
 	if (MondayFirst) JulianToday -= (JulianToday%7);
 	else             JulianToday -= ((JulianToday+1)%7);
 
+        GenerateCalEntries(-1);
+
 	if (!DoSimpleCalendar) {
   	    WriteWeekHeaderLine();
 	    WriteCalDays();
@@ -584,7 +646,7 @@ void ProduceCalendar(void)
 static void DoCalendarOneWeek(int nleft)
 {
     int y, m, d, done, i, l, wd;
-    char buf[81];
+    char buf[128];
     int LinesWritten = 0;
     int OrigJul = JulianToday;
 
@@ -612,8 +674,8 @@ static void DoCalendarOneWeek(int nleft)
     goff();
     for (i=0; i<7; i++) {
 	FromJulian(OrigJul+i, &y, &m, &d);
-	sprintf(buf, "%d %c%c%c ", d, MonthName[m][0], MonthName[m][1],
-		MonthName[m][2]);
+        char const *mon = get_month_name(m);
+        snprintf(buf, sizeof(buf), "%d %s ", d, get_month_abbrev(mon));
 	if (OrigJul+i == RealToday)
 	    PrintLeft(buf, ColSpaces, '*');
 	else
@@ -622,7 +684,7 @@ static void DoCalendarOneWeek(int nleft)
 	DRAW(tb);
 	goff();
     }
-    PutChar('\n');
+    putchar('\n');
     for (l=0; l<CalPad; l++) {
 	gon();
 	DRAW(tb);
@@ -633,7 +695,7 @@ static void DoCalendarOneWeek(int nleft)
 	    DRAW(tb);
 	    goff();
 	}
-	PutChar('\n');
+	putchar('\n');
     }
 
 /* Write the body lines */
@@ -654,7 +716,7 @@ static void DoCalendarOneWeek(int nleft)
 	    DRAW(tb);
 	    goff();
 	}
-	PutChar('\n');
+	putchar('\n');
     }
 
 /* Write the final line */
@@ -674,7 +736,7 @@ static void DoCalendarOneWeek(int nleft)
 /***************************************************************/
 static void DoCalendarOneMonth(void)
 {
-    int y, m, d, mm, yy;
+    int y, m, d, mm, yy, i, j;
 
     if (!DoSimpleCalendar) WriteCalHeader();
 
@@ -694,20 +756,26 @@ static void DoCalendarOneMonth(void)
 	}
 	if (PsCal < PSCAL_LEVEL3) {
 	    printf("%s %d %d %d %d\n",
-		   MonthName[m], y, DaysInMonth(m, y), (JulianToday+1) % 7,
+		   despace(get_month_name(m)), y, DaysInMonth(m, y), (JulianToday+1) % 7,
 		   MondayFirst);
-	    printf("%s %s %s %s %s %s %s\n",
-		   DayName[6], DayName[0], DayName[1], DayName[2],
-		   DayName[3], DayName[4], DayName[5]);
+            for (i=0; i<7; i++) {
+                j=(i+6)%7;
+                if (i) {
+                    printf(" %s", despace(get_day_name(j)));
+                } else {
+                    printf("%s", despace(get_day_name(j)));
+                }
+            }
+            printf("\n");
 	} else {
-	    PrintJSONKeyPairString("monthname", MonthName[m]);
+	    PrintJSONKeyPairString("monthname", get_month_name(m));
 	    PrintJSONKeyPairInt("year", y);
 	    PrintJSONKeyPairInt("daysinmonth", DaysInMonth(m, y));
 	    PrintJSONKeyPairInt("firstwkday", (JulianToday+1) % 7);
 	    PrintJSONKeyPairInt("mondayfirst", MondayFirst);
 	    printf("\"daynames\":[\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\",\"%s\"],",
-		   DayName[6], DayName[0], DayName[1], DayName[2],
-		   DayName[3], DayName[4], DayName[5]);
+		   get_day_name(6), get_day_name(0), get_day_name(1), get_day_name(2),
+		   get_day_name(3), get_day_name(4), get_day_name(5));
 	}
 	mm = m-1;
 	if (mm<0) {
@@ -715,9 +783,9 @@ static void DoCalendarOneMonth(void)
 	} else yy=y;
 
 	if (PsCal < PSCAL_LEVEL3) {
-	    printf("%s %d\n", MonthName[mm], DaysInMonth(mm,yy));
+	    printf("%s %d\n", despace(get_month_name(mm)), DaysInMonth(mm,yy));
 	} else {
-	    PrintJSONKeyPairString("prevmonthname", MonthName[mm]);
+	    PrintJSONKeyPairString("prevmonthname", get_month_name(mm));
 	    PrintJSONKeyPairInt("daysinprevmonth", DaysInMonth(mm, yy));
 	    PrintJSONKeyPairInt("prevmonthyear", yy);
 	}
@@ -726,9 +794,9 @@ static void DoCalendarOneMonth(void)
 	    mm = 0; yy = y+1;
 	} else yy=y;
 	if (PsCal < PSCAL_LEVEL3) {
-	    printf("%s %d\n", MonthName[mm], DaysInMonth(mm,yy));
+	    printf("%s %d\n", despace(get_month_name(mm)), DaysInMonth(mm,yy));
 	} else {
-	    PrintJSONKeyPairString("nextmonthname", MonthName[mm]);
+	    PrintJSONKeyPairString("nextmonthname", get_month_name(mm));
 	    PrintJSONKeyPairInt("daysinnextmonth", DaysInMonth(mm, yy));
 	    PrintJSONKeyPairInt("nextmonthyear", yy);
 	    printf("\"entries\":[\n");
@@ -797,9 +865,9 @@ static int WriteCalendarRow(void)
 	    PrintLeft("", ColSpaces, ' ');
 	else {
 	    sprintf(buf, "%d ", d+i-wd);
-	    if (OrigJul+i == RealToday) {
+	    if (Julian(y, m, d+i-wd) == RealToday) {
 		PrintLeft(buf, ColSpaces-1, '*');
-		PutChar(' ');
+		putchar(' ');
 	    } else {
 		PrintLeft(buf, ColSpaces, ' ');
 	    }
@@ -808,7 +876,7 @@ static int WriteCalendarRow(void)
 	DRAW(tb);
 	goff();
     }
-    PutChar('\n');
+    putchar('\n');
     for (l=0; l<CalPad; l++) {
         gon();
 	DRAW(tb);
@@ -819,7 +887,7 @@ static int WriteCalendarRow(void)
 	    DRAW(tb);
 	    goff();
 	}
-	PutChar('\n');
+	putchar('\n');
     }
 
 /* Write the body lines */
@@ -840,7 +908,7 @@ static int WriteCalendarRow(void)
 	    DRAW(tb);
 	    goff();
 	}
-	PutChar('\n');
+	putchar('\n');
     }
 
     moreleft = (d+7-wd <= DaysInMonth(m, y));
@@ -863,9 +931,54 @@ static int WriteCalendarRow(void)
 /***************************************************************/
 static void PrintLeft(char const *s, int width, char pad)
 {
+#ifndef REM_USE_WCHAR
     int len = strlen(s);
     printf("%s", s);
-    while (len++ < width) PutChar(pad);
+    while (len++ < width) putchar(pad);
+#else
+    size_t len = mbstowcs(NULL, s, 0);
+    int i;
+    wchar_t static_buf[128];
+    wchar_t *buf;
+    wchar_t *ws;
+    int display_len;
+
+    if (!len) {
+	for (i=0; i<width; i++) {
+	    fputc(pad, stdout);
+	}
+	return;
+    }
+    if (len + 1 <= 128) {
+	buf = static_buf;
+    } else {
+	buf = calloc(len+1, sizeof(wchar_t));
+	if (!buf) {
+	    /* Uh-oh... cannot recover */
+	    fprintf(stderr, "%s\n", ErrMsg[E_NO_MEM]);
+	    exit(1);
+	}
+    }
+    (void) mbstowcs(buf, s, len+1);
+    display_len = wcswidth(buf, len+1);
+
+    ws = buf;
+    for (i=0; i<width;) {
+	if (*ws) {
+            PutWideChar(*ws++);
+            i+= wcwidth(*ws);
+        } else {
+            break;
+        }
+    }
+    /* Mop up any potential combining characters */
+    while (*ws && wcwidth(*ws) == 0) {
+        PutWideChar(*ws++);
+    }
+    for (i=display_len; i<width; i++) fputc(pad, stdout);
+    if (buf != static_buf) free(buf);
+#endif
+
 }
 
 /***************************************************************/
@@ -886,10 +999,10 @@ static void PrintCentered(char const *s, int width, char *pad)
     for (i=0; i<width; i++) {
 	if (*s) {
             if (isspace(*s)) {
-                PutChar(' ');
+                putchar(' ');
                 s++;
             } else {
-                PutChar(*s++);
+                putchar(*s++);
             }
         } else {
             break;
@@ -942,7 +1055,7 @@ static void PrintCentered(char const *s, int width, char *pad)
     while (*ws && wcwidth(*ws) == 0) {
         PutWideChar(*ws++);
     }
-    for (i=d+len; i<width; i++) fputs(pad, stdout);
+    for (i=d+display_len; i<width; i++) fputs(pad, stdout);
     if (buf != static_buf) free(buf);
 #endif
 }
@@ -971,7 +1084,7 @@ static int WriteOneCalLine(void)
 	DRAW(tb);
 	goff();
     }
-    PutChar('\n');
+    putchar('\n');
 
     return done;
 }
@@ -1044,7 +1157,7 @@ static int WriteOneColLine(int col)
 	    for (ws = e->wc_pos; ws - e->wc_pos < ColSpaces; ws++) {
 		if (!*ws) break;
                 if (iswspace(*ws)) {
-                    PutChar(' ');
+                    putchar(' ');
                     numwritten++;
                 } else {
                     if (wcwidth(*ws) > 0) {
@@ -1059,7 +1172,7 @@ static int WriteOneColLine(int col)
 	    for (ws = e->wc_pos; ws<wspace; ws++) {
 		if (!*ws) break;
                 if (iswspace(*ws)) {
-                    PutChar(' ');
+                    putchar(' ');
                     numwritten++;
                 } else {
                     if (wcwidth(*ws) > 0) {
@@ -1076,7 +1189,7 @@ static int WriteOneColLine(int col)
 	}
 
 	/* Flesh out the rest of the column */
-	while(numwritten++ < ColSpaces) PutChar(' ');
+	while(numwritten++ < ColSpaces) putchar(' ');
 
 	/* Skip any spaces before next word */
 	while (iswspace(*ws)) ws++;
@@ -1131,9 +1244,9 @@ static int WriteOneColLine(int col)
 		if (!*s) break;
 		numwritten++;
                 if (isspace(*s)) {
-                    PutChar(' ');
+                    putchar(' ');
                 } else {
-                    PutChar(*s);
+                    putchar(*s);
                 }
 	    }
 	    e->pos = s;
@@ -1143,9 +1256,9 @@ static int WriteOneColLine(int col)
 		if (!*s) break;
 		numwritten++;
                 if (isspace(*s)) {
-                    PutChar(' ');
+                    putchar(' ');
                 } else {
-                    PutChar(*s);
+                    putchar(*s);
                 }
 	    }
 	}
@@ -1156,7 +1269,7 @@ static int WriteOneColLine(int col)
 	}
 
 	/* Flesh out the rest of the column */
-	while(numwritten++ < ColSpaces) PutChar(' ');
+	while(numwritten++ < ColSpaces) putchar(' ');
 
 	/* Skip any spaces before next word */
 	while (isspace(*s)) s++;
@@ -1238,7 +1351,10 @@ static void GenerateCalEntries(int col)
 	    case T_IfTrig:  r=DoIfTrig(&p);  break;
 	    case T_Else:    r=DoElse(&p);    break;
 	    case T_EndIf:   r=DoEndif(&p);   break;
-	    case T_Include: r=DoInclude(&p); break;
+
+	    case T_Include:
+	    case T_IncludeR: r=DoInclude(&p, tok.type); break;
+
 	    case T_IncludeCmd: r=DoIncludeCmd(&p); break;
 	    case T_Exit:    DoExit(&p);	     break;
 	    case T_Set:     r=DoSet(&p);     break;
@@ -1296,7 +1412,7 @@ static void WriteCalHeader(void)
     int y, m, d;
 
     FromJulian(JulianToday, &y, &m, &d);
-    sprintf(buf, "%s %d", MonthName[m], y);
+    sprintf(buf, "%s %d", get_month_name(m), y);
 
     WriteTopCalLine();
 
@@ -1307,7 +1423,7 @@ static void WriteCalHeader(void)
     gon();
     DRAW(tb);
     goff();
-    PutChar('\n');
+    putchar('\n');
 
     WritePostHeaderLine();
     WriteCalDays();
@@ -1321,7 +1437,7 @@ static void WriteCalHeader(void)
 /***************************************************************/
 static void WriteCalTrailer(void)
 {
-    PutChar('\f');
+    putchar('\f');
 }
 
 /***************************************************************/
@@ -1333,13 +1449,13 @@ static void WriteCalTrailer(void)
 /***************************************************************/
 static int DoCalRem(ParsePtr p, int col)
 {
-    int oldLen;
+    size_t oldLen;
     Trigger trig;
     TimeTrig tim;
     Value v;
     int r, err;
     int jul;
-    CalEntry *CurCol = CalColumn[col];
+    CalEntry *CurCol;
     CalEntry *e;
     char const *s, *s2;
     DynamicBuffer buf, obuf, pre_buf, raw_buf;
@@ -1348,6 +1464,11 @@ static int DoCalRem(ParsePtr p, int col)
 
     int is_color, col_r, col_g, col_b;
 
+    if (col >= 0) {
+        CurCol = CalColumn[col];
+    } else {
+        CurCol = NULL;
+    }
     is_color = 0;
     DBufInit(&buf);
     DBufInit(&pre_buf);
@@ -1373,11 +1494,6 @@ static int DoCalRem(ParsePtr p, int col)
 	}
     }
 
-/* Don't include timed reminders in calendar if -a option supplied. */
-    if (DontIssueAts && tim.ttime != NO_TIME) {
-	FreeTrig(&trig);
-	return OK;
-    }
     if (trig.typ == NO_TYPE) {
 	FreeTrig(&trig);
 	return E_EOLN;
@@ -1440,6 +1556,27 @@ static int DoCalRem(ParsePtr p, int col)
 	}
     }
 
+    /* Add to global OMITs if so indicated */
+    if (trig.addomit) {
+        r = AddGlobalOmit(jul);
+        if (r) {
+	    FreeTrig(&trig);
+            return r;
+        }
+    }
+
+    /* If we're not actually generating any calendar entries, we're done */
+    if (col < 0) {
+	FreeTrig(&trig);
+        return OK;
+    }
+
+    /* Don't include timed reminders in calendar if -a option supplied. */
+    if (DontIssueAts && tim.ttime != NO_TIME) {
+	FreeTrig(&trig);
+	return OK;
+    }
+
     /* Save nonconst_expr flag */
     nonconst_expr = p->nonconst_expr;
     /* Convert PS and PSF to PASSTHRU */
@@ -1665,7 +1802,9 @@ static int DoCalRem(ParsePtr p, int col)
 	if(!e->filename) {
 	    if (e->text) free(e->text);
 	    if (e->raw_text) free(e->raw_text);
+#ifdef REM_USE_WCHAR
             if (e->wc_text) free(e->wc_text);
+#endif
 	    free(e);
 	    return E_NO_MEM;
 	}
@@ -1754,7 +1893,7 @@ static void WriteSimpleEntryProtocol2(CalEntry *e, int today)
 		printf("\"%s\"", EnglishDayName[i]);
 	    }
 	}
-	printf("], ");
+	printf("],");
     }
     if (e->trig.d != NO_DAY) {
 	PrintJSONKeyPairInt("d", e->trig.d);
@@ -1807,7 +1946,7 @@ static void WriteSimpleEntryProtocol2(CalEntry *e, int today)
 		printf("\"%s\"", EnglishDayName[i]);
 	    }
 	}
-	printf("], ");
+	printf("],");
     }
     PrintJSONKeyPairDate("until", e->trig.until);
     if (e->trig.once != NO_ONCE) {
@@ -1876,7 +2015,7 @@ static void WriteSimpleEntries(int col, int jul)
 		}
 	    }
 	    DidADay = 1;
-	    printf("{\"date\":\"%04d-%02d-%02d\", ", y, m+1, d);
+	    printf("{\"date\":\"%04d-%02d-%02d\",", y, m+1, d);
 	    WriteSimpleEntryProtocol2(e, jul);
 	    printf("}");
 	    if (PsCal != PSCAL_LEVEL3) {
@@ -1912,7 +2051,7 @@ static void WriteTopCalLine(void)
     PrintCentered("", CalWidth-2, linestruct->lr);
     DRAW(bl);
     goff();
-    PutChar('\n');
+    putchar('\n');
 }
 
 static void WriteBottomCalLine(void)
@@ -1929,7 +2068,7 @@ static void WriteBottomCalLine(void)
 	}
     }
     goff();
-    PutChar('\n');
+    putchar('\n');
 }
 
 static void WritePostHeaderLine(void)
@@ -1946,7 +2085,7 @@ static void WritePostHeaderLine(void)
 	}
     }
     goff();
-    PutChar('\n');
+    putchar('\n');
 }
 
 static void WriteWeekHeaderLine(void)
@@ -1963,7 +2102,7 @@ static void WriteWeekHeaderLine(void)
 	}
     }
     goff();
-    PutChar('\n');
+    putchar('\n');
 }
 
 static void WriteIntermediateCalLine(void)
@@ -1981,7 +2120,7 @@ static void WriteIntermediateCalLine(void)
 	}
     }
     goff();
-    PutChar('\n');
+    putchar('\n');
 }
 
 static void WriteCalDays(void)
@@ -1992,14 +2131,14 @@ static void WriteCalDays(void)
     goff();
     for (i=0; i<7; i++) {
 	if (!MondayFirst)
-	    PrintCentered(DayName[(i+6)%7], ColSpaces, " ");
+	    PrintCentered(get_day_name((i+6)%7), ColSpaces, " ");
 	else
-	    PrintCentered(DayName[i%7], ColSpaces, " ");
+	    PrintCentered(get_day_name(i%7), ColSpaces, " ");
 	gon();
 	DRAW(tb);
 	goff();
     }
-    PutChar('\n');
+    putchar('\n');
 }
 
 /***************************************************************/
