@@ -11,22 +11,18 @@
 /***************************************************************/
 
 /*---------------------------------------------------------------------*/
-/* LAT_DEG, LAT_MIN and LAT_SEC: Latitude of your location             */
-/* LON_DEG, LON_MIN and LON_SEC: Longitude of your location            */
+/* DEFAULT_LATITUDE: Latitude of your location                         */
+/* DEFAULT_LONGITUDE: Longitude of your location                       */
 /* LOCATION: A string identifying your location.                       */
-/* All latitude and longitude numbers should be positive for the       */
-/* northern and western hemisphere.  If you live in the southern       */
-/* hemisphere, ALL latitude values should be negative.  If you live    */
-/* in the eastern hemisphere, ALL longitude values should be negative. */
+/* Latitude and longitude should be positive for the                   */
+/* northern and eastern hemisphere and negative for the southern and   */
+/* western hemisphere.                                                 */
 /*                                                                     */
-/* The default values are initially set to Ottawa, Ontario, Canada.    */
+/* The default values are initially set to the city hall in Ottawa,    */
+/* Ontario, Canada.    */
 /*---------------------------------------------------------------------*/
-#define LAT_DEG 45
-#define LAT_MIN 24
-#define LAT_SEC  0
-#define LON_DEG 75
-#define LON_MIN 39
-#define LON_SEC  0
+#define DEFAULT_LATITUDE 45.42055555555555
+#define DEFAULT_LONGITUDE -75.68972222222223
 #define LOCATION "Ottawa"
 
 /*---------------------------------------------------------------------*/
@@ -58,45 +54,6 @@
 #define DATETIMESEP '@'
 /* #define DATETIMESEP '/' */
 
-/*---------------------------------------------------------------------*/
-/* ISOLATIN1: define it to 1 if you use the                            */
-/* ISO 8859-1 character set instead of ASCII.                          */
-/*---------------------------------------------------------------------*/
-#define ISOLATIN1 1
-
-/*---------------------------------------------------------------------*/
-/* ISOLATIN2: define it to 1 if you use the                            */
-/* ISO 8859-2 character set instead of ASCII.                          */
-/* NOT ALL LANGUAGE MODULES SUPPORT THIS.  Note that at most one of    */
-/* ISOLATIN1, ISOLATIN2, IBMEXTENDED and IBM852 should be 1; if more   */
-/* then one are defined as 1, the results are unspecified.             */
-/*---------------------------------------------------------------------*/
-#define ISOLATIN2 0
-
-/*---------------------------------------------------------------------*/
-/* IBMEXTENDED: define as 1 if your system uses the  IBM extended      */
-/* character set.                                                      */
-/* NOT ALL LANGUAGE MODULES SUPPORT THIS.  Note that at most one of    */
-/* ISOLATIN1, ISOLATIN2, IBMEXTENDED and IBM852 should be 1; if more   */
-/* then one are defined as 1, the results are unspecified.             */
-/*---------------------------------------------------------------------*/
-#define IBMEXTENDED 0
-
-/*---------------------------------------------------------------------*/
-/* IBM852: define as 1 if your system uses the IBM CPI-852 extended    */
-/* character set.                                                      */
-/* NOT ALL LANGUAGE MODULES SUPPORT THIS.  Note that at most one of    */
-/* ISOLATIN1, ISOLATIN2, IBMEXTENDED and IBM852 should be 1; if more   */
-/* then one are defined as 1, the results are unspecified.             */
-/*---------------------------------------------------------------------*/
-#define IBM852 0
-
-/*---------------------------------------------------------------------*/
-/* WANT_U_OPTION: Comment out the next define to permanently disable   */
-/* the -u option.                                                      */
-/*---------------------------------------------------------------------*/
-#define WANT_U_OPTION 1
-
 /**********************************************************************/
 /**********************************************************************/
 /**********************************************************************/
@@ -114,16 +71,7 @@
 /* WANT_SHELL_ESCAPING:  Define this if you want special shell         */
 /* characters to be escaped with a backslash for the -k option.        */
 /*---------------------------------------------------------------------*/
-#if defined(UNIX)
 #define WANT_SHELL_ESCAPING 1
-#endif
-
-/*---------------------------------------------------------------------*/
-/* Some implementations have a broken 'putc' and 'putchar'.            */
-/*---------------------------------------------------------------------*/
-#ifdef __SASC_60
-#define BROKEN_PUTC
-#endif
 
 /*---------------------------------------------------------------------*/
 /* BASE: The base year for date calculation.  NOTE!  January 1 of the  */
@@ -189,7 +137,7 @@
 /*---------------------------------------------------------------------*/
 /* How many global omits of the form YYYY MM DD do we handle?          */
 /*---------------------------------------------------------------------*/
-#define MAX_FULL_OMITS 500
+#define MAX_FULL_OMITS 1000
 
 /*---------------------------------------------------------------------*/
 /* How many global omits of the form MM DD do we handle?               */
@@ -223,14 +171,6 @@
 #define PSBEGIN2 "# rem2ps2 begin"
 #define PSEND2   "# rem2ps2 end"
 
-#ifdef BROKEN_PUTC
-#define Putc SafePutc
-#define PutChar SafePutChar
-#else
-#define Putc putc
-#define PutChar putchar
-#endif
-
 #if defined(HAVE_MBSTOWCS) && defined(HAVE_WCTYPE_H)
 #define REM_USE_WCHAR 1
 #else
