@@ -141,6 +141,14 @@ int DoRem(ParsePtr p)
 	}
     }
 
+    /* Add to global OMITs if so indicated */
+    if (trig.addomit) {
+        r = AddGlobalOmit(jul);
+        if (r) {
+	    FreeTrig(&trig);
+            return r;
+        }
+    }
     if (PurgeMode) {
 	if (trig.expired || jul < JulianToday) {
 	    if (p->expr_happened) {
@@ -211,6 +219,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
     trig->localomit = NO_WD;
     trig->skip = NO_SKIP;
     trig->once = NO_ONCE;
+    trig->addomit = 0;
     trig->typ = NO_TYPE;
     trig->scanfrom = NO_DATE;
     trig->from = NO_DATE;
@@ -225,7 +234,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
     DBufInit(&(trig->tags));
     trig->passthru[0] = 0;
     tim->ttime = NO_TIME;
-    tim->delta = NO_DELTA;
+    tim->delta = DefaultTDelta;
     tim->rep   = NO_REP;
     tim->duration = NO_TIME;
     if (save_in_globals) {
@@ -280,6 +289,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 	    break;
 
         case T_MaybeUncomputable:
+	    DBufFree(&buf);
             trig->maybe_uncomputable = 1;
             break;
 
@@ -374,6 +384,11 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 	    trig->once = ONCE_ONCE;
 	    break;
 
+        case T_AddOmit:
+	    DBufFree(&buf);
+            trig->addomit = 1;
+            break;
+
 	case T_Omit:
 	    DBufFree(&buf);
 	    if (trig->omitfunc[0]) {
@@ -474,7 +489,7 @@ static int ParseTimeTrig(ParsePtr s, TimeTrig *tim, int save_in_globals)
 {
     Token tok;
     int r;
-
+    int seen_delta = 0;
     DynamicBuffer buf;
     DBufInit(&buf);
 
@@ -491,8 +506,9 @@ static int ParseTimeTrig(ParsePtr s, TimeTrig *tim, int save_in_globals)
 
 	case T_Delta:
 	    DBufFree(&buf);
-	    if (tim->delta != NO_DELTA) return E_DELTA_TWICE;
-	    tim->delta = (tok.val > 0) ? tok.val : -tok.val;
+            if (seen_delta) return E_DELTA_TWICE;
+            seen_delta = 1;
+	    tim->delta = (tok.val >= 0) ? tok.val : -tok.val;
 	    break;
 
 	case T_Rep:
@@ -1143,9 +1159,9 @@ int DoSatRemind(Trigger *trig, TimeTrig *tt, ParsePtr p)
 		FromJulian(LastTriggerDate, &y, &m, &d);
 		fprintf(ErrFp, "%s(%d): Trig(satisfied) = %s, %d %s, %d",
 			FileName, LineNo,
-			DayName[LastTriggerDate % 7],
+			get_day_name(LastTriggerDate % 7),
 			d,
-			MonthName[m],
+			get_month_name(m),
 			y);
 		if (tt->ttime != NO_TIME) {
 		    fprintf(ErrFp, " AT %02d:%02d",
