@@ -557,23 +557,68 @@ static int PopFile(void)
 /*  The INCLUDE command.                                       */
 /*                                                             */
 /***************************************************************/
-int DoInclude(ParsePtr p)
+int DoInclude(ParsePtr p, enum TokTypes tok)
 {
     DynamicBuffer buf;
+    DynamicBuffer fullname;
+    DynamicBuffer path;
     int r, e;
 
+    r = OK;
+    char const *s;
     DBufInit(&buf);
+    DBufInit(&fullname);
+    DBufInit(&path);
     if ( (r=ParseToken(p, &buf)) ) return r;
     e = VerifyEoln(p);
     if (e) Eprint("%s", ErrMsg[e]);
-    if ( (r=IncludeFile(DBufValue(&buf))) ) {
-	DBufFree(&buf);
-	return r;
+
+    if (tok == T_IncludeR && *(DBufValue(&buf)) != '/') {
+        /* Relative include: Include relative to dir
+           containing current file */
+        if (DBufPuts(&path, FileName) != OK) {
+            r = E_NO_MEM;
+            goto bailout;
+        }
+        if (DBufLen(&path) == 0) {
+            s = DBufValue(&buf);
+        } else {
+            char *t = DBufValue(&path) + DBufLen(&path) - 1;
+            while (t > DBufValue(&path) && *t != '/') t--;
+            if (*t == '/') {
+                *t = 0;
+                if (DBufPuts(&fullname, DBufValue(&path)) != OK) {
+                    r = E_NO_MEM;
+                    goto bailout;
+                }
+                if (DBufPuts(&fullname, "/") != OK) {
+                    r = E_NO_MEM;
+                    goto bailout;
+                }
+                if (DBufPuts(&fullname, DBufValue(&buf)) != OK) {
+                    r = E_NO_MEM;
+                    goto bailout;
+                }
+                s = DBufValue(&fullname);
+            } else {
+                s = DBufValue(&buf);
+            }
+        }
+    } else {
+        s = DBufValue(&buf);
     }
-    DBufFree(&buf);
+    if ( (r=IncludeFile(s)) ) {
+        goto bailout;
+    }
+
     NumIfs = 0;
     IfFlags = 0;
-    return OK;
+
+  bailout:
+    DBufFree(&buf);
+    DBufFree(&path);
+    DBufFree(&fullname);
+    return r;
 }
 
 /***************************************************************/
@@ -1039,7 +1084,8 @@ int TopLevel(void)
 /*  root, we refuse to open files not owned by root.           */
 /*  We also reject world-writable files, no matter             */
 /*  who we're running as.                                      */
-/*  As a side effect, if we don't own the file, we disable RUN */
+/*  As a side effect, if we don't own the file, or it's not    */
+/*  owned by a trusted user, we disable RUN                    */
 /***************************************************************/
 static int CheckSafety(void)
 {
@@ -1077,11 +1123,22 @@ static int CheckSafety(void)
 	return 0;
     }
 
-/* If file is not owned by me, disable RUN command */
-    if (statbuf.st_uid != geteuid()) {
-	RunDisabled |= RUN_NOTOWNER;
-    } else {
+    /* If file is not owned by me or a trusted user, disable RUN command */
+
+    /* Assume unsafe */
+    RunDisabled |= RUN_NOTOWNER;
+    if (statbuf.st_uid == geteuid()) {
+        /* Owned by me... safe */
 	RunDisabled &= ~RUN_NOTOWNER;
+    } else {
+        int i;
+        for (i=0; i<NumTrustedUsers; i++) {
+            if (statbuf.st_uid == TrustedUsers[i]) {
+                /* Owned by a trusted user... safe */
+                RunDisabled &= ~RUN_NOTOWNER;
+                break;
+            }
+        }
     }
 
     return 1;
