@@ -58,6 +58,7 @@ static int FADusk          (func_info *);
 static int FAbs            (func_info *);
 static int FAccess         (func_info *);
 static int FAmpm           (func_info *);
+static int FIsAny          (func_info *);
 static int FArgs           (func_info *);
 static int FAsc            (func_info *);
 static int FBaseyr         (func_info *);
@@ -239,6 +240,7 @@ BuiltinFunc Func[] = {
     {   "hour",         1,      1,      1,          FHour   },
     {   "iif",          1,      NO_MAX, 1,          FIif    },
     {   "index",        2,      3,      1,          FIndex  },
+    {   "isany",        1,      NO_MAX, 1,          FIsAny  },
     {   "isdst",        0,      2,      0,          FIsdst },
     {   "isleap",       1,      1,      1,          FIsleap },
     {   "isomitted",    1,      1,      0,          FIsomitted },
@@ -409,8 +411,9 @@ static int RetStrVal(char const *s, func_info *info)
     if (!s) {
 	RetVal.v.str = malloc(1);
 	if (RetVal.v.str) *RetVal.v.str = 0;
-    } else
+    } else {
 	RetVal.v.str = StrDup(s);
+    }
 
     if (!RetVal.v.str) {
 	RetVal.type = ERR_TYPE;
@@ -430,7 +433,9 @@ static int FStrlen(func_info *info)
     Value *v = &ARG(0);
     if (v->type != STR_TYPE) return E_BAD_TYPE;
     RetVal.type = INT_TYPE;
-    RETVAL = strlen(v->v.str);
+    size_t l = strlen(v->v.str);
+    if (l > INT_MAX) return E_2HIGH;
+    RETVAL = (int) l;
     return OK;
 }
 
@@ -786,8 +791,8 @@ static int FWkday(func_info *info)
 	/* Convert 0=Sun to 0=Mon */
 	ARGV(0)--;
 	if (ARGV(0) < 0) ARGV(0) = 6;
-	s = DayName[ARGV(0)];
-    } else s = DayName[DATEPART(ARG(0)) % 7];
+	s = get_day_name(ARGV(0));
+    } else s = get_day_name(DATEPART(ARG(0)) % 7);
     return RetStrVal(s, info);
 }
 
@@ -814,7 +819,7 @@ static int FMon(func_info *info)
 	    CacheDay = d;
 	}
     }
-    s = MonthName[m];
+    s = get_month_name(m);
     return RetStrVal(s, info);
 }
 
@@ -1033,6 +1038,36 @@ static int FPlural(func_info *info)
     }
 }
 
+/***************************************************************/
+/*                                                             */
+/*  FIsAny                                                     */
+/*  Return 1 if the first arg equals any subsequent arg, 0     */
+/*  otherwise.                                                 */
+/*                                                             */
+/***************************************************************/
+static int FIsAny(func_info *info)
+{
+    int i;
+    RetVal.type = INT_TYPE;
+    RETVAL = 0;
+    for (i=1; i<Nargs; i++) {
+        if (ARG(0).type == ARG(i).type) {
+            if (ARG(0).type == STR_TYPE) {
+                if (!strcmp(ARGSTR(0), ARGSTR(i))) {
+                    RETVAL = 1;
+                    return OK;
+                }
+            } else {
+                if (ARGV(0) == ARGV(i)) {
+                    RETVAL = 1;
+                    return OK;
+                }
+            }
+        }
+    }
+    return OK;
+}
+
 /***************************************************************/
 /*                                                             */
 /*  FChoose                                                    */
@@ -1539,6 +1574,15 @@ static int FShell(func_info *info)
 	ASSERT_TYPE(1, INT_TYPE);
 	maxlen = ARGV(1);
     }
+
+    /* Don't allow maxlen to exceed the maximum length of
+       a string variable */
+    if (MaxStringLen > 0) {
+        if (maxlen <= 0 || maxlen > MaxStringLen) {
+            maxlen = MaxStringLen;
+        }
+    }
+
     fp = popen(ARGSTR(0), "r");
     if (!fp) return E_IO_ERR;
     while (1) {
@@ -1552,7 +1596,7 @@ static int FShell(func_info *info)
 	    DBufFree(&buf);
 	    return E_NO_MEM;
 	}
-	if (maxlen > 0 && DBufLen(&buf) >= maxlen) {
+	if (maxlen > 0 && DBufLen(&buf) >= (size_t) maxlen) {
 	    break;
 	}
     }
@@ -2113,12 +2157,8 @@ static int SunStuff(int rise, double cosz, int jul)
     } else mins = MinsFromUTC;
 
 /* Get latitude and longitude */
-    longdeg = (double) LongDeg + (double) LongMin / 60.0
-	+ (double) LongSec / 3600.0;
-
-    latitude = DEGRAD * ((double) LatDeg + (double) LatMin / 60.0
-			 + (double) LatSec / 3600.0);
-
+    longdeg = -Longitude;
+    latitude = DEGRAD * Latitude;
 
     FromJulian(jul, &year, &mon, &day);
 
@@ -2372,6 +2412,7 @@ static int FPsshade(func_info *info)
     if (!psshade_warned) {
 	psshade_warned = 1;
 	Eprint("psshade() is deprecated; use SPECIAL SHADE instead.");
+        FreshLine = 1;
     }
 
     sprintf(s, "/_A LineWidth 2 div def ");
@@ -2427,6 +2468,7 @@ static int FPsmoon(func_info *info)
     if (!psmoon_warned) {
 	psmoon_warned = 1;
 	Eprint("psmoon() is deprecated; use SPECIAL MOON instead.");
+        FreshLine = 1;
     }
     if (size > 0) {
 	sprintf(sizebuf, "%d", size);
