@@ -44,7 +44,7 @@ void PrintValue  (Value *v, FILE *fp);
 int CopyValue (Value *dest, const Value *src);
 int ReadLine (void);
 int OpenFile (char const *fname);
-int DoInclude (ParsePtr p);
+int DoInclude (ParsePtr p, enum TokTypes tok);
 int DoIncludeCmd (ParsePtr p);
 int IncludeFile (char const *fname);
 int GetAccessDate (char const *file);
@@ -163,3 +163,9 @@ void PrintJSONKeyPairDateTime(char const *name, int dt);
 void PrintJSONKeyPairTime(char const *name, int t);
 void System(char const *cmd);
 int ShellEscape(char const *in, DynamicBuffer *out);
+int AddGlobalOmit(int jul);
+void set_lat_and_long_from_components(void);
+void set_components_from_lat_and_long(void);
+
+char const *get_day_name(int wkday);
+char const *get_month_name(int mon);
