@@ -146,9 +146,9 @@ put_escaped_string(char const *s)
 {
     while(*s) {
         if (*s == '\\' || *s == '(' || *s == ')') {
-            PutChar('\\');
+            putchar('\\');
         }
-        PutChar(*s);
+        putchar(*s);
         s++;
     }
 }
@@ -383,6 +383,7 @@ void DoPsCal(void)
     int firstcol;
     DynamicBuffer buf;
     CalEntry *c, *d, *p;
+    char *s;
 
 /* Read the month and year name, followed by # days in month and 1st day of
    month */
@@ -391,12 +392,28 @@ void DoPsCal(void)
     sscanf(DBufValue(&buf), "%s %s %d %d %d", month, year, &days, &wkday,
 	   &MondayFirst);
 
+    /* Replace underscores in month name with spaces */
+    s = month;
+    while(*s) {
+        if (*s == '_') *s = ' ';
+        s++;
+    }
+
     /* Get day names */
     DBufGets(&buf, stdin);
     sscanf(DBufValue(&buf), "%32s %32s %32s %32s %32s %32s %32s",
 	   DayName[0], DayName[1], DayName[2], DayName[3],
 	   DayName[4], DayName[5], DayName[6]);
 
+    /* Replace underscores in day names with spaces */
+    for (i=0; i<7; i++) {
+        s = DayName[i];
+        while(*s) {
+            if (*s == '_') *s = ' ';
+            s++;
+        }
+    }
+
     /* We write the prolog here because it's only at this point that
        MondayFirst is set correctly. */
     if (validfile == 1) {
@@ -407,6 +424,19 @@ void DoPsCal(void)
     sscanf(DBufValue(&buf), "%s %d", prevm, &prevdays);
     DBufGets(&buf, stdin);
     sscanf(DBufValue(&buf), "%s %d", nextm, &nextdays);
+
+    /* Replace underscores with spaces in names of next/prev month */
+    s = prevm;
+    while(*s) {
+        if (*s == '_') *s = ' ';
+        s++;
+    }
+    s = nextm;
+    while(*s) {
+        if (*s == '_') *s = ' ';
+        s++;
+    }
+
     DBufFree(&buf);
     MaxDay = days;
     FirstWkDay = wkday;
@@ -595,7 +625,7 @@ void WriteProlog(void)
 	strcmp(SmallFont, DayFont)  &&
 	strcmp(TitleFont, SmallFont) &&
 	strcmp(SmallFont, EntryFont)) printf(" %s", SmallFont);
-    PutChar('\n');
+    putchar('\n');
     printf("%%%%Creator: Rem2PS\n");
     printf("%%%%Pages: (atend)\n");
     printf("%%%%Orientation: %s\n", PortraitMode ? "Portrait" : "Landscape");
@@ -775,20 +805,20 @@ void WriteOneEntry(CalEntry *c)
 	}
     }
 
-    PutChar('(');
+    putchar('(');
     while(*s) {
 	/* Use the "unsigned char" cast to fix problem on Solaris 2.5 */
 	/* which treated some latin1 characters as white space.       */
 	ch = (unsigned char) *s++;
-	if (ch == '\\' || ch == '(' || ch == ')') PutChar('\\');
-	if (!isspace(ch)) PutChar(ch);
+	if (ch == '\\' || ch == '(' || ch == ')') putchar('\\');
+	if (!isspace(ch)) putchar(ch);
 	else {
-	    PutChar(')');
+	    putchar(')');
 	    while(isspace((unsigned char)*s)) s++;
 	    if (!*s) {
 		goto finish;
 	    }
-	    PutChar('(');
+	    putchar('(');
 	}
     }
     printf(")\n");
