@@ -5,7 +5,8 @@
 ALL=`grep ^#define lang.h | grep -v '#define LANG' | awk '{print $2}'`
 
 for i in $ALL ; do
-    make clean all LANGDEF=-DLANG=$i || exit 1
+    make clean
+    make -j`nproc` all LANGDEF=-DLANG=$i || exit 1
     ./remind -q -r ../tests/tstlang.rem
 done
 exit 0
