@@ -37,7 +37,7 @@ while (isdigit(*(string))) { \
    Keep this array sorted, or software will not work. */
 Token TokArray[] = {
     /* NAME          MINLEN      TYPE           VALUE */
-
+    { "addomit",        7,      T_AddOmit,      0 },
     { "after",		3,	T_Skip,	AFTER_SKIP },
     { "april",		3,	T_Month,	3 },
     { "at",		2,	T_At,		0 },
@@ -48,6 +48,7 @@ Token TokArray[] = {
     { "clear-omit-context", 5,   T_Clr,         0 },
     { "debug",          5,      T_Debug,       0 },
     { "december",	3,	T_Month,       11 },
+    { "do",     	2,	T_IncludeR,	0 },
     { "dumpvars",       4,      T_Dumpvars,    0 },
     { "duration",       3,      T_Duration,     0 },
     { "else",		4,	T_Else,	0 },
@@ -104,33 +105,6 @@ Token TokArray[] = {
     { "wednesday",	3,	T_WkDay,	2 }
 };
 
-/* If language != English, we must also search the following... */
-#if LANG != ENGLISH
-Token NonEnglishToks[] = {
-    /* NAME          MINLEN      TYPE           VALUE */
-
-    { L_MONDAY,	       3,       T_WkDay,        0 },
-    { L_TUESDAY,       3,       T_WkDay,        1 },
-    { L_WEDNESDAY,     3,       T_WkDay,        2 },
-    { L_THURSDAY,      3,       T_WkDay,        3 },
-    { L_FRIDAY,	       3,       T_WkDay,        4 },
-    { L_SATURDAY,      3,       T_WkDay,        5 },
-    { L_SUNDAY,	       3,       T_WkDay,        6 },
-    { L_JAN,           3,       T_Month,        0 },
-    { L_FEB,           3,       T_Month,        1 },
-    { L_MAR,           3,       T_Month,        2 },
-    { L_APR,           3,       T_Month,        3 },
-    { L_MAY,           3,       T_Month,        4 },
-    { L_JUN,           3,       T_Month,        5 },
-    { L_JUL,           3,       T_Month,        6 },
-    { L_AUG,           3,       T_Month,        7 },
-    { L_SEP,           3,       T_Month,        8 },
-    { L_OCT,           3,       T_Month,        9 },
-    { L_NOV,           3,       T_Month,        10 },
-    { L_DEC,           3,       T_Month,        11 }
-};
-#endif
-
 static int TokStrCmp (Token const *t, char const *s);
 
 /***************************************************************/
@@ -173,6 +147,10 @@ void FindToken(char const *s, Token *tok)
     int top, bot, mid, r, max;
     int l;
 
+#if LANG != ENGLISH
+    size_t i;
+#endif
+
     tok->type = T_Illegal;
     if (! *s) {
 	tok->type = T_Empty;
@@ -227,19 +205,6 @@ void FindToken(char const *s, Token *tok)
 	if (r > 0) top = mid-1; else bot=mid+1;
     }
 
-/* If language is other than English, search the DayNames[] and MonthNames[]
-   array. */
-#if LANG != ENGLISH
-    for (size_t x=0; x<(sizeof(NonEnglishToks) / sizeof(Token)); x++) {
-	if (l >= NonEnglishToks[x].MinLen &&
-	    !TokStrCmp(&NonEnglishToks[x], s)) {
-	    tok->type = NonEnglishToks[x].type;
-	    tok->val = NonEnglishToks[x].val;
-	    return;
-	}
-    }
-#endif
-
     return;
 }
 
@@ -333,9 +298,6 @@ void FindNumericToken(char const *s, Token *t)
 	/* If we hit a non-digit, error! */
 	if (*s) return;
 
-	/* Special hack - convert years between 90 and 99 to 1990 and 1999 */
-	if (t->val >= 90 && t->val <= 99) t->val += 1900;
-
 	/* Classify the number we've got */
 	if (t->val >= BASE && t->val <= BASE+YR_RANGE) t->type = T_Year;
 	else if (t->val >= 1 && t->val <= 31) t->type = T_Day;
